@@ -3,6 +3,7 @@
 import logging
 import hashlib
 import codecs
+import os
 from os import path
 import time
 import ecdsa
@@ -10,7 +11,6 @@ import nacl.signing
 import unidecode
 
 from . import interface
-from ..gpg import keyring
 
 # import pgpy
 # from pgpy import PGPKey
@@ -62,9 +62,7 @@ class OnlyKey(interface.Device):
 
     def get_sk_dk(self):
         """Get signing key and decryption key slots from config."""
-        fpath = keyring.get_agent_sock_path()
-        fpath = fpath.decode()
-        fpath = fpath.replace("S.gpg-agent", "run-agent.sh")
+        fpath = os.path.join(os.environ.get('AGENTHOMEDIR', os.environ.get('GNUPGHOME')), 'run-agent.sh')
         log.debug('Path to run-agent.sh = %s', fpath)
         if path.exists(fpath):
             with open(fpath) as f:
