@@ -1,20 +1,20 @@
 """TREZOR-related definitions."""
 
+import logging
 # pylint: disable=unused-import,import-error,no-name-in-module,no-member
 import os
-import logging
 
 import mnemonic
 import semver
+
 import trezorlib
-
-from trezorlib.client import TrezorClient as Client, PASSPHRASE_TEST_PATH
-from trezorlib.exceptions import TrezorFailure, PinException
-from trezorlib.transport import get_transport
-from trezorlib.messages import IdentityType
-
 from trezorlib.btc import get_address, get_public_node
-from trezorlib.misc import sign_identity, get_ecdh_session_key
+from trezorlib.client import PASSPHRASE_TEST_PATH
+from trezorlib.client import TrezorClient as Client
+from trezorlib.exceptions import PinException, TrezorFailure
+from trezorlib.messages import IdentityType
+from trezorlib.misc import get_ecdh_session_key, sign_identity
+from trezorlib.transport import get_transport
 
 log = logging.getLogger(__name__)
 
@@ -28,3 +28,4 @@ def find_device():
         return get_transport(os.environ.get("TREZOR_PATH"))
     except Exception as e:  # pylint: disable=broad-except
         log.debug("Failed to find a Trezor device: %s", e)
+        return None
