@@ -137,6 +137,9 @@ def run_init(device_type, args):
     homedir = args.homedir
     if not homedir:
         homedir = os.path.expanduser('~/.gnupg/{}'.format(device_name))
+        
+    # Save homedir as environment variable
+    os.environ['AGENTHOMEDIR']=homedir
 
     log.info('GPG home directory: %s', homedir)
 
@@ -201,7 +204,7 @@ else
 fi
 """.format(homedir))
     check_call(['chmod', '700', f.name])
-
+   
     # Generate new GPG identity and import into GPG keyring
     pubkey = write_file(os.path.join(homedir, 'pubkey.asc'),
                         export_public_key(device_type, args))
@@ -267,6 +270,9 @@ def run_agent(device_type):
     args, _ = p.parse_known_args()
 
     assert args.homedir
+    
+    # Save homedir as environment variable
+    os.environ['AGENTHOMEDIR']=args.homedir
 
     log_file = os.path.join(args.homedir, 'gpg-agent.log')
     util.setup_logging(verbosity=args.verbose, filename=log_file)
@@ -372,4 +378,4 @@ def main(device_type):
     else:
         device_type.ui = device.ui.UI(device_type=device_type, config=vars(args))
 
-    return args.func(device_type=device_type, args=args)
+    return args.func(device_type=device_type, args=args)
\ No newline at end of file
